#pragma once

/* SPDX-License-Identifier: GPL-3.0-or-later OR BSL-1.0 OR CC0-1.0 OR CC-PDCC OR 0BSD */

#include <avnd/concepts/attributes.hpp>
#include <avnd/concepts/audio_port.hpp>
#include <avnd/concepts/audio_processor.hpp>
#include <avnd/concepts/callback.hpp>
#include <avnd/concepts/channels.hpp>
#include <avnd/concepts/control.hpp>
#include <avnd/concepts/curve.hpp>
#include <avnd/concepts/dynamic_ports.hpp>
#include <avnd/concepts/fft.hpp>
#include <avnd/concepts/field_names.hpp>
#include <avnd/concepts/file_port.hpp>
#include <avnd/concepts/generic.hpp>
#include <avnd/concepts/gfx.hpp>
#include <avnd/concepts/init.hpp>
#include <avnd/concepts/layout.hpp>
#include <avnd/concepts/logger.hpp>
#include <avnd/concepts/mapper.hpp>
#include <avnd/concepts/message.hpp>
#include <avnd/concepts/message_bus.hpp>
#include <avnd/concepts/midi.hpp>
#include <avnd/concepts/midi_port.hpp>
#include <avnd/concepts/midifile.hpp>
#include <avnd/concepts/modules.hpp>
#include <avnd/concepts/object.hpp>
#include <avnd/concepts/painter.hpp>
#include <avnd/concepts/parameter.hpp>
#include <avnd/concepts/port.hpp>
#include <avnd/concepts/processor.hpp>
#include <avnd/concepts/range.hpp>
#include <avnd/concepts/schedule.hpp>
#include <avnd/concepts/smooth.hpp>
#include <avnd/concepts/soundfile.hpp>
#include <avnd/concepts/synth.hpp>
#include <avnd/concepts/temporality.hpp>
#include <avnd/concepts/ui.hpp>
#include <avnd/concepts/widget.hpp>
#include <avnd/concepts/worker.hpp>
